@@ -7,10 +7,10 @@
     Copyright (c) 2002,2003,2004 by Will Stephenson <will@stevello.free-online.co.uk>
 
     Kopete    (c) 2002,2003,2004 by the Kopete developers  <kopete-devel@kde.org>
-	
-	Purpose: 
-	This class abstracts the interface to amaroK by
-	implementing NLMediaPlayer
+
+    Purpose:
+    This class abstracts the interface to amaroK by
+    implementing NLMediaPlayer
 
     *************************************************************************
     *                                                                       *
@@ -25,20 +25,19 @@
 #ifndef NLAMAROK_H
 #define NLAMAROK_H
 
-#include <QtDBus/QtDBus>
+#include <QtDBus>
 #include "nlmediaplayer.h"
 
 class QDBusInterface;
 
 class NLamaroK : public NLMediaPlayer
 {
-	public:
-		NLamaroK();
-		virtual ~NLamaroK();
-		virtual void update();
-	private:
-		QDBusInterface *m_client;
+public:
+    NLamaroK();
+    virtual ~NLamaroK();
+    virtual void update();
+private:
+    QDBusInterface *m_client;
 };
 
 #endif
-
